<template>
  <div>
    <!--Calendar examples-->
    <div class="calendar-examples">
      <Calendar>
        <template #footer> This is the footer </template>
      </Calendar>
      <Calendar
        v-if="false"
        :attributes="attributes"
        :columns="$screens({ default: 1, md: 2 })"
        transition="slide-h"
        :masks="{ weekdays: 'WWW' }"
        show-weeknumbers="right-outside"
      >
        <template #day-popover="{}"> Helloooo </template>
      </Calendar>
      <Calendar
        v-if="false"
        class="custom-calendar max-w-full"
        :attributes="customAttributes"
        disable-page-swipe
        is-expanded
      >
        <template v-slot:day-content="{ day, attributes }">
          <div class="flex flex-col h-full z-10 overflow-hidden">
            <span class="day-label text-sm text-gray-900">{{ day.day }}</span>
            <div class="flex-grow overflow-y-auto overflow-x-auto">
              <p
                v-for="attr in attributes"
                :key="attr.key"
                class="text-xs leading-tight rounded-sm p-1 mt-0 mb-1"
                :class="attr.customData.class"
              >
                {{ attr.customData.title }}
              </p>
            </div>
          </div>
        </template>
      </Calendar>
    </div>
    <!--Datepicker examples-->
    <div class="date-examples">
      <div>
        <div>
          <label for="dark">
            <input id="dark" type="checkbox" v-model="isDark" />
            Is Dark</label
          >
          <label for="range">
            <input id="range" type="checkbox" v-model="isRange" />
            Is Range</label
          >
        </div>
        <div>
          <label for="date">
            <input id="date" type="radio" v-model="mode" value="date" />
            date
          </label>
          <label for="datetime">
            <input id="datetime" type="radio" v-model="mode" value="datetime" />
            datetime</label
          >
          <label for="time">
            <input id="time" type="radio" v-model="mode" value="time" />
            time</label
          >
        </div>
        <DatePicker
          :mode="mode"
          v-model="date"
          :is-dark="isDark"
          :is-range="isRange"
        >
          <template #footer>
            <div class="flex w-full justify-between">This is the footer</div>
          </template>
        </DatePicker>
      </div>
      <div>
        <DatePicker
          :mode="mode"
          v-model="date"
          :is-dark="isDark"
          :is-range="isRange"
        >
          <template #default="{ inputValue, inputEvents }">
            <template v-if="isRange">
              <input :value="inputValue.start" v-on="inputEvents.start" />
              <input :value="inputValue.end" v-on="inputEvents.end" />
            </template>
            <template v-else>
              <input :value="inputValue" v-on="inputEvents" />
            </template>
          </template>
        </DatePicker>
      </div>
    </div>
  </div>
</template>

<script>
export default {
  name: 'App',
  data() {
    const month = new Date().getMonth();
    const year = new Date().getFullYear();

    return {
      date: new Date(),
      mode: 'datetime',
      isDark: false,
      isRange: false,
      attributes: [
        {
          highlight: true,
          popover: {
            label: 'Testing',
          },
          dates: [new Date(), new Date(2020, 10, 12)],
        },
        {
          dot: true,
          dates: new Date(2020, 10, 5),
        },
      ],
      customAttributes: [
        {
          key: 1,
          customData: {
            title: 'Lunch with mom.',
            class: 'bg-red-600 text-white',
          },
          dates: new Date(year, month, 1),
        },
        {
          key: 2,
          customData: {
            title: 'Take Noah to basketball practice',
            class: 'bg-blue-500 text-white',
          },
          dates: new Date(year, month, 2),
        },
        {
          key: 3,
          customData: {
            title: "Noah's basketball game.",
            class: 'bg-blue-500 text-white',
          },
          dates: new Date(year, month, 5),
        },
        {
          key: 4,
          customData: {
            title: 'Take car to the shop',
            class: 'bg-indigo-500 text-white',
          },
          dates: new Date(year, month, 5),
        },
        {
          key: 4,
          customData: {
            title: 'Meeting with new client.',
            class: 'bg-teal-500 text-white',
          },
          dates: new Date(year, month, 7),
        },
        {
          key: 5,
          customData: {
            title: "Mia's gymnastics practice.",
            class: 'bg-pink-500 text-white',
          },
          dates: new Date(year, month, 11),
        },
        {
          key: 6,
          customData: {
            title: 'Cookout with friends.',
            class: 'bg-orange-500 text-white',
          },
          dates: { months: 5, ordinalWeekdays: { 2: 1 } },
        },
        {
          key: 7,
          customData: {
            title: "Mia's gymnastics recital.",
            class: 'bg-pink-500 text-white',
          },
          dates: new Date(year, month, 22),
        },
        {
          key: 8,
          customData: {
            title: 'Visit great grandma.',
            class: 'bg-red-600 text-white',
          },
          dates: new Date(year, month, 25),
        },
      ],
    };
  },
  watch: {
    isRange(val) {
      if (val) {
        this.date = {
          start: new Date(2020, 10, 16),
          end: new Date(2020, 10, 20),
        };
      } else {
        this.date = new Date();
      }
    },
  },
};
</script>

<style scoped>
.calendar-examples {
  margin: 2rem;
}
.date-examples {
  margin: 2rem;
  display: flex;
}
</style>

<style lang="postcss" scoped>
::-webkit-scrollbar {
  width: 0px;
}
::-webkit-scrollbar-track {
  display: none;
}
/deep/ .custom-calendar.vc-container {
  --day-border: 1px solid #b8c2cc;
  --day-border-highlight: 1px solid #b8c2cc;
  --day-width: 90px;
  --day-height: 90px;
  --weekday-bg: #f8fafc;
  --weekday-border: 1px solid #eaeaea;
  border-radius: 0;
  width: 100%;
  & .vc-header {
    background-color: #f1f5f8;
    padding: 10px 0;
  }
  & .vc-weeks {
    padding: 0;
  }
  & .vc-weekday {
    background-color: var(--weekday-bg);
    border-bottom: var(--weekday-border);
    border-top: var(--weekday-border);
    padding: 5px 0;
  }
  & .vc-day {
    padding: 0 5px 3px 5px;
    text-align: left;
    height: var(--day-height);
    min-width: var(--day-width);
    background-color: white;
    &.weekday-1,
    &.weekday-7 {
      background-color: #eff8ff;
    }
    &:not(.on-bottom) {
      border-bottom: var(--day-border);
      &.weekday-1 {
        border-bottom: var(--day-border-highlight);
      }
    }
    &:not(.on-right) {
      border-right: var(--day-border);
    }
  }
  & .vc-day-dots {
    margin-bottom: 5px;
  }
}
</style>
